@@ -1,5 +1,3 @@
-# $Id: CelticMale.pm,v 1.3 2005/05/22 17:02:28 peterhickman Exp $
-
 package Data::RandomPerson::Names::CelticMale;
 
 use strict;
@@ -14,9 +12,76 @@ sub new {
 
     my $self = bless {}, $class;
 
-	$self->{choice} = Data::RandomPerson::Choice->new();
+    $self->{choice} = Data::RandomPerson::Choice->new();
 
-	$self->{choice}->add_list( qw/
+    my @names = <DATA>;
+    close DATA;
+    chomp (@names);
+    $self->{choice}->add_list(@names);
+
+    return $self;
+}
+
+1;
+
+=pod
+
+=head1 NAME
+
+Data::RandomPerson::Names::CelticMale - A list of male names
+
+=head1 SYNOPSIS
+
+  use Data::RandomPerson::Names::CelticMale;
+
+  my $n = Data::RandomPerson::Names::CelticMale->new();
+
+  print $n->get();
+
+=head1 DESCRIPTION
+
+=head2 Overview
+
+Returns a random element from a list of male names culled from Chris Pound's language machines
+page at L<http://generators.christopherpound.com/>.
+
+=head2 Constructors and initialization
+
+=over 4
+
+=item new( )
+
+Create the Data::RandomPerson::Names::CelticMale object.
+
+=back
+
+=head2 Class and object methods
+
+=over 4
+
+=item get( )
+
+Returns a random name from the list.
+
+=item size( )
+
+Returns the size of the list
+
+=back
+
+=head1 AUTHOR
+
+Peter Hickman (peterhi@ntlworld.com)
+
+=head1 COPYRIGHT
+
+Copyright (c) 2005, Peter Hickman. This module is
+free software. It may be used, redistributed and/or modified under the
+same terms as Perl itself.
+
+=cut
+
+__DATA__
 abaris
 abban
 aberth
@@ -1995,87 +2060,3 @@ nnae
 osg
 gn
 istean
-			  / );
-
-    return $self;
-}
-
-1;
-
-__END__
-=head1 NAME
-
-Data::RandomPerson::Names::CelticMale - A list of male names
-
-=head1 VERSION
-
-This document refers to version 0.4 of Data::RandomPerson::Names::CelticMale, released Sept 13th, 2005
-
-=head1 SYNOPSIS
-
-  use Data::RandomPerson::Names::CelticMale;
-
-  my $n = Data::RandomPerson::Names::CelticMale->new();
-
-  print $n->get();
-
-=head1 DESCRIPTION
-
-=head2 Overview
-
-Returns a random element from a list of male names culled from Chris Pound's language machines
-page at http://www.ruf.rice.edu/~pound/#scripts.
-
-=head2 Constructors and initialization
-
-=over 4
-
-=item new( )
-
-Create the Data::RandomPerson::Names::CelticMale object.
-
-=back
-
-=head2 Class and object methods
-
-=over 4
-
-=item get( )
-
-Returns a random name from the list.
-
-=item size( )
-
-Returns the size of the list
-
-=back
-
-=head1 ENVIRONMENT
-
-Perl 5
-
-=head1 DIAGNOSTICS
-
-None
-
-=head1 BUGS
-
-None so far
-
-=head1 FILES
-
-None
-
-=head1 SEE ALSO
-
-None
-
-=head1 AUTHOR
-
-Peter Hickman (peterhi@ntlworld.com)
-
-=head1 COPYRIGHT
-
-Copyright (c) 2005, Peter Hickman. All rights reserved. This module is
-free software. It may be used, redistributed and/or modified under the
-same terms as Perl itself.
